sequencetools.Sequence
======================

.. abjad-lineage:: abjad.tools.sequencetools.Sequence.Sequence

.. autoclass:: abjad.tools.sequencetools.Sequence.Sequence

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.sequencetools.Sequence.Sequence.degree_of_rotational_symmetry
      ~abjad.tools.sequencetools.Sequence.Sequence.is_decreasing
      ~abjad.tools.sequencetools.Sequence.Sequence.is_increasing
      ~abjad.tools.sequencetools.Sequence.Sequence.is_permutation
      ~abjad.tools.sequencetools.Sequence.Sequence.is_repetition_free
      ~abjad.tools.sequencetools.Sequence.Sequence.is_restricted_growth_function
      ~abjad.tools.sequencetools.Sequence.Sequence.period_of_rotation
      ~abjad.tools.sequencetools.Sequence.Sequence.reverse
      ~abjad.tools.sequencetools.Sequence.Sequence.rotate
      ~abjad.tools.sequencetools.Sequence.Sequence.__add__
      ~abjad.tools.sequencetools.Sequence.Sequence.__eq__
      ~abjad.tools.sequencetools.Sequence.Sequence.__format__
      ~abjad.tools.sequencetools.Sequence.Sequence.__getitem__
      ~abjad.tools.sequencetools.Sequence.Sequence.__getslice__
      ~abjad.tools.sequencetools.Sequence.Sequence.__hash__
      ~abjad.tools.sequencetools.Sequence.Sequence.__len__
      ~abjad.tools.sequencetools.Sequence.Sequence.__ne__
      ~abjad.tools.sequencetools.Sequence.Sequence.__radd__
      ~abjad.tools.sequencetools.Sequence.Sequence.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.Sequence.Sequence.degree_of_rotational_symmetry
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Sequence.Sequence.period_of_rotation
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.is_decreasing
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.is_increasing
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.is_permutation
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.is_repetition_free
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.is_restricted_growth_function
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.reverse
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.rotate
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__add__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__eq__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__format__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__getitem__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__getslice__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__hash__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__len__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__ne__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__radd__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Sequence.Sequence.__repr__
   :noindex:
